@@ -18,7 +18,6 @@
 import sys
 
 messages = {}
-messages['NoDeployment'] = r'You have to append the deployment name.'
 messages['WrongApplication'] = r'This application is unknown.'
 messages['WrongDeployment'] = r'This deployment is unknown.'
 messages['PasswordsDontMatch'] = r"The passwords don't match."
@@ -73,6 +72,7 @@ messages['NoPreviousVersionFound'] = r'Previous version not found.'
 messages['ClearCacheFailed'] = r'Clear buildpack cache failed.'
 messages['DeploymentFailed'] = r'Deployment failed.'
 messages['CommandNotImplemented'] = r'Sorry, this command is not available.'
+messages['ShipAndDeploy'] = r'--ship and --push options cannot be used simultaneously.'
 
 if sys.platform == 'win32':
     messages['UpdateAvailable'] = r'A newer version is available. Please update.'
